@@ -13,17 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from __future__ import annotations
 
 from collections.abc import Generator
 import logging
 import random
-from typing import Any, Callable, TypeVar, cast
+from typing import Any, Callable, TypeVar
 
 from bleak import BleakClient
 from bleak.backends.characteristic import BleakGATTCharacteristic
-from bleak_retry_connector import BLEAK_RETRY_EXCEPTIONS as BLEAK_EXCEPTIONS
 
 from aiohomekit.controller.ble.key import DecryptionKey, EncryptionKey
 from aiohomekit.exceptions import EncryptionError
@@ -60,32 +58,6 @@ class PDUStatusError(Exception):
         self.status = status
 
 
-def retry_bluetooth_connection_error(attempts: int = DEFAULT_ATTEMPTS) -> WrapFuncType:
-    """Define a wrapper to retry on bluetooth connection error."""
-
-    def _decorator_retry_bluetooth_connection_error(func: WrapFuncType) -> WrapFuncType:
-        """Define a wrapper to retry on bleak error.
-
-        The accessory is allowed to disconnect us any time so
-        we need to retry the operation.
-        """
-
-        async def _async_wrap(*args: Any, **kwargs: Any) -> Any:
-            for attempt in range(attempts):
-                try:
-                    return await func(*args, **kwargs)
-                except BLEAK_EXCEPTIONS:
-                    if attempt == attempts - 1:
-                        raise
-                    logger.debug(
-                        "Bleak error calling %s, retrying...", func, exc_info=True
-                    )
-
-        return cast(WrapFuncType, _async_wrap)
-
-    return cast(WrapFuncType, _decorator_retry_bluetooth_connection_error)
-
-
 async def ble_request(
     client: AIOHomeKitBleakClient,
     encryption_key: EncryptionKey | None,
