@@ -474,7 +474,7 @@ class BlePairing(AbstractPairing):
                 *BLEAK_EXCEPTIONS,
                 AccessoryNotFoundError,
             ) as exc:
-                logger.warning(
+                logger.exception(
                     "%s: Failed to fetch disconnected events: %s; rssi=%s",
                     self.name,
                     exc,
@@ -557,15 +557,28 @@ class BlePairing(AbstractPairing):
             "%s: Received notification but could not decrypt: %s", self.name, data
         )
 
-    async def _async_set_broadcast_encryption_key(self) -> None:
-        """Get the broadcast key for the accessory."""
+    def _async_get_service_signature_char(self) -> Characteristic | None:
+        """Get the service signature characteristic."""
         info = self.accessories.aid(1).services.first(
             service_type=ServicesTypes.PROTOCOL_INFORMATION
         )
         if not info:
             logger.debug("%s: No signature service found", self.name)
+            return None
+        if not info.has(CharacteristicsTypes.SERVICE_SIGNATURE):
+            logger.debug(
+                "%s: No signature characteristic found, "
+                "accessory may not implement encrypted notifications",
+                self.name,
+            )
+            return None
+        return info[CharacteristicsTypes.SERVICE_SIGNATURE]
+
+    async def _async_set_broadcast_encryption_key(self) -> None:
+        """Get the broadcast key for the accessory."""
+        hap_char = self._async_get_service_signature_char()
+        if not hap_char:
             return
-        hap_char = info[CharacteristicsTypes.SERVICE_SIGNATURE]
         service_iid = hap_char.service.iid
         logger.debug(
             "%s: Setting broadcast key for service_iid: %s",
@@ -644,8 +657,14 @@ class BlePairing(AbstractPairing):
                     continue
 
                 decoded = CharacteristicTLV.decode(signature).to_dict()
+                normalized_uuid = normalize_uuid(char.uuid)
 
-                hap_char = s.add_char(normalize_uuid(char.uuid))
+                if normalized_uuid == CharacteristicsTypes.IDENTIFY:
+                    # Workaround for older eve v1 devices which has a broken identify characteristic
+                    # that presents identify as data.
+                    decoded["format"] = "bool"
+
+                hap_char = s.add_char(normalized_uuid)
                 logger.debug("%s: char: %s decoded: %s", self.name, char, decoded)
 
                 hap_char.iid = iid
@@ -741,19 +760,16 @@ class BlePairing(AbstractPairing):
 
     @operation_lock
     @retry_bluetooth_connection_error()
+    @restore_connection_and_resume
     async def get_all_protocol_params(self) -> ProtocolParams | None:
         """Get the global state number."""
         return await self._get_all_protocol_params()
 
     async def _get_all_protocol_params(self) -> ProtocolParams | None:
         """Get the current protocol params number."""
-        info = self.accessories.aid(1).services.first(
-            service_type=ServicesTypes.PROTOCOL_INFORMATION
-        )
-        if not info:
-            logger.debug("%s: No signature service found", self.name)
-            return None
-        hap_char = info[CharacteristicsTypes.SERVICE_SIGNATURE]
+        hap_char = self._async_get_service_signature_char()
+        if not hap_char:
+            return
         service_iid = hap_char.service.iid
         try:
             resp = await self._async_request(
@@ -777,7 +793,7 @@ class BlePairing(AbstractPairing):
                 response[ProtocolParamsTLV.ConfigurationNumber], "little"
             ),
             advertising_id=response[ProtocolParamsTLV.AdvertisingId],
-            broadcast_key=response[ProtocolParamsTLV.BroadcastKey],
+            broadcast_key=response.get(ProtocolParamsTLV.BroadcastKey),
         )
         logger.debug(
             "%s: Fetched protocol params: gsn=%s, c#=%s",
